Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(586)

Unified Diff: src/gpu/GrProgramElement.cpp

Issue 574333003: Rename GrProgramResource to GrGpuResourceRef (Closed) Base URL: https://skia.googlesource.com/skia.git@master
Patch Set: add newline before private: Created 6 years, 3 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « src/gpu/GrGpuResourceRef.cpp ('k') | src/gpu/GrProgramResource.cpp » ('j') | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: src/gpu/GrProgramElement.cpp
diff --git a/src/gpu/GrProgramElement.cpp b/src/gpu/GrProgramElement.cpp
index 20a957f7c7ca9c3eea14da883c50bb1416d195ab..2c3085f7e4bbfc39df39e30b1b6e67af5f988650 100644
--- a/src/gpu/GrProgramElement.cpp
+++ b/src/gpu/GrProgramElement.cpp
@@ -6,7 +6,7 @@
*/
#include "GrProgramElement.h"
-#include "GrProgramResource.h"
+#include "GrGpuResourceRef.h"
uint32_t GrProgramElement::CreateUniqueID() {
static int32_t gUniqueID = SK_InvalidUniqueID;
@@ -18,21 +18,21 @@ uint32_t GrProgramElement::CreateUniqueID() {
}
void GrProgramElement::convertRefToPendingExecution() const {
// This function makes it so that all the GrProgramResources own a single ref to their
// underlying GrGpuResource if there are any refs to the GrProgramElement and a single
// pending read/write if there are any pending executions of the GrProgramElement. The
// GrProgramResource will give up its single ref and/or pending read/write in its destructor.
SkASSERT(fRefCnt > 0);
if (0 == fPendingExecutions) {
- for (int i = 0; i < fProgramResources.count(); ++i) {
- fProgramResources[i]->markPendingIO();
+ for (int i = 0; i < fGpuResources.count(); ++i) {
+ fGpuResources[i]->markPendingIO();
}
}
++fPendingExecutions;
this->unref();
if (0 == fRefCnt) {
- for (int i = 0; i < fProgramResources.count(); ++i) {
- fProgramResources[i]->removeRef();
+ for (int i = 0; i < fGpuResources.count(); ++i) {
+ fGpuResources[i]->removeRef();
}
}
}
@@ -46,8 +46,8 @@ void GrProgramElement::completedExecution() const {
} else {
// Now our pending executions have ocurred and we still have refs. Convert
// ownership of our resources back to regular refs.
- for (int i = 0; i < fProgramResources.count(); ++i) {
- fProgramResources[i]->pendingIOComplete();
+ for (int i = 0; i < fGpuResources.count(); ++i) {
+ fGpuResources[i]->pendingIOComplete();
}
}
« no previous file with comments | « src/gpu/GrGpuResourceRef.cpp ('k') | src/gpu/GrProgramResource.cpp » ('j') | no next file with comments »
@@ -18,21 +18,21 @@ uint32_t GrProgramElement::CreateUniqueID() {
}
void GrProgramElement::convertRefToPendingExecution() const {
- // This function makes it so that all the GrProgramResources own a single ref to their
+ // This function makes it so that all the GrGpuResourceRefs own a single ref to their
// underlying GrGpuResource if there are any refs to the GrProgramElement and a single
// pending read/write if there are any pending executions of the GrProgramElement. The
@@ -18,21 +18,21 @@ uint32_t GrProgramElement::CreateUniqueID() {
// underlying GrGpuResource if there are any refs to the GrProgramElement and a single
// pending read/write if there are any pending executions of the GrProgramElement. The
- // GrProgramResource will give up its single ref and/or pending read/write in its destructor.
+ // GrGpuResourceRef will give up its single ref and/or pending read/write in its destructor.
SkASSERT(fRefCnt > 0);
if (0 == fPendingExecutions) {

Powered by Google App Engine
This is Rietveld 408576698